0.2.0
---

- Use geoshop id for error handling now.


0.2.0
---

- Fix bug when fields are not set in geoshop, now it is printed out to the console but the lib keeps running


0.1.0
---

- Initial version.
- implements first views for connection data sets
